@@ -1,8 +1,4 @@
 from .schema import (
-    TableSchema,
-    TableSchemaOpts,
-    ModelSchema,
-    ModelSchemaOpts,
     SQLAlchemySchema,
     SQLAlchemyAutoSchema,
     SQLAlchemySchemaOpts,
@@ -19,7 +15,7 @@ from .convert import (
 )
 from .exceptions import ModelConversionError
 
-__version__ = "0.24.2"
+__version__ = "0.27.0"
 __all__ = [
     "SQLAlchemySchema",
     "SQLAlchemyAutoSchema",
@@ -32,9 +28,4 @@ __all__ = [
     "column2field",
     "ModelConversionError",
     "field_for",
-    # Deprecated API
-    "TableSchema",
-    "TableSchemaOpts",
-    "ModelSchema",
-    "ModelSchemaOpts",
 ]
